@@ -60,34 +60,26 @@ func TestSingleScript(t *testing.T) {
 
 	var scripts = []enginetest.ScriptTest{
 		{
-			Name: "row_count() behavior",
-			SetUpScript: []string{
-				"create table b (x int primary key)",
-				"insert into b values (1), (2), (3), (4)",
-			},
+			// All DECLARE statements are only allowed under BEGIN/END blocks
+			Name: "Top-level DECLARE statements",
 			Assertions: []enginetest.ScriptTestAssertion{
 				{
-					Query:    "delete from b where x <> 2",
-					Expected: []sql.Row{{sql.NewOkResult(3)}},
-				},
-				{
-					Query:    "select * from b where x <> 2",
-					Expected: []sql.Row{},
-				},
-				{
-					Query:    "replace into b values (1)",
-					Expected: []sql.Row{{sql.NewOkResult(1)}},
-				},
-				{
-					Query:    "select row_count()",
-					Expected: []sql.Row{{1}},
+					Query:    "select 1+1",
+					Expected: []sql.Row{{2}},
 				},
 			},
 		},
+		{
+			Name: "last_insert_id() behavior",
+			SetUpScript: []string{
+				"create table a (x int primary key, y int)",
+			},
+			Assertions: []enginetest.ScriptTestAssertion{},
+		},
 	}
 
+	harness := newDoltHarness(t)
 	for _, test := range scripts {
-		harness := newDoltHarness(t)
 		engine := enginetest.NewEngine(t, harness)
 		engine.Analyzer.Debug = true
 		engine.Analyzer.Verbose = true
@@ -307,3 +299,13 @@ func TestStoredProcedures(t *testing.T) {
 
 	enginetest.TestStoredProcedures(t, newDoltHarness(t))
 }
+
+func TestTransactions(t *testing.T) {
+	if !sqle.TransactionsEnabled {
+		sqle.TransactionsEnabled = true
+		defer func() {
+			sqle.TransactionsEnabled = false
+		}()
+	}
+	enginetest.TestTransactionScripts(t, newDoltHarness(t))
+}
